==> centreon-web-24.10.19.tar.gz: centreon-web-24.10.19/www/install/react_translation.php <==
<?php
/*
 * Copyright 2005-2019 Centreon
 * Centreon is developed by : Julien Mathis and Romain Le Merlus under
 * GPL Licence 2.0.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation ; either version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, see <http://www.gnu.org/licenses>.
 *
 * Linking this program statically or dynamically with other modules is making a
 * combined work based on this program. Thus, the terms and conditions of the GNU
 * General Public License cover the whole combination.
 *
 * As a special exception, the copyright holders of this program give Centreon
 * permission to link this program with independent modules to produce an executable,
 * regardless of the license terms of these independent modules, and to copy and
 * distribute the resulting executable under terms of Centreon choice, provided that
 * Centreon also meet, for each linked independent module, the terms and conditions
 * of the license of that module. An independent module is a module which is not
 * derived from this program. If you modify this program, you may extend this
 * exception to your version of the program, but you are not obliged to do so. If you
 * do not wish to do so, delete this exception statement from your version.
 *
 * For more information : contact@centreon.com
 *
 */

echo _('All pollers');
echo _('Configure pollers');
echo _('services');
echo _('Critical services');
echo _('Warning services');
echo _('Unknown services');
echo _('Ok services');
echo _('Pending services');
echo _('Edit profile');
echo _('Copy autologin link');
echo _('Server Configuration Wizard');
echo _('Choose a server type');
echo _('Add a Centreon Remote Server');
echo _('Add a Centreon Poller');
echo _('Remote Server Configuration');
echo _('Create new Remote Server');
echo _('Server Name');
echo _('Server address');
echo _('Database username');
echo _('Database password');
echo _('Centreon Central address, as seen by this server');
echo _('Centreon Web Folder on Remote');
echo _('Select Pending Remote Links');
echo _('Select IP');
echo _('Select pollers to be attached to this new Remote Server');
echo _('Finalizing Setup');
echo _('Creating Export Task');
echo _('Generating Export Files');
echo _('The field is required');
echo _('Not a valid IP address');
echo _('Add server with wizard');
echo _('Select linked Remote Server');
echo _('as');
echo _('Server Configuration');
echo _('Attach poller to a master remote server');
echo _('Attach poller to additional remote servers');
echo _('Advanced: reverse Centreon Broker communication flow');
echo _('%s is not valid.');
echo _("You need to send '%s' in the request.");
echo _("Some database poller updates are not active; check your configuration");
echo _("Latency detected, check configuration for better optimization");
echo _("Do not check SSL certificate validation");
echo _("Do not use configured proxy to connect to this server");

==> centreon-web-24.10.21.tar.gz: centreon-web-24.10.21/www/install/react_translation.php <==
<?php

/*
 * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

echo _('All pollers');
echo _('Configure pollers');
echo _('services');
echo _('Critical services');
echo _('Warning services');
echo _('Unknown services');
echo _('Ok services');
echo _('Pending services');
echo _('Edit profile');
echo _('Copy autologin link');
echo _('Server Configuration Wizard');
echo _('Choose a server type');
echo _('Add a Centreon Remote Server');
echo _('Add a Centreon Poller');
echo _('Remote Server Configuration');
echo _('Create new Remote Server');
echo _('Server Name');
echo _('Server address');
echo _('Database username');
echo _('Database password');
echo _('Centreon Central address, as seen by this server');
echo _('Centreon Web Folder on Remote');
echo _('Select Pending Remote Links');
echo _('Select IP');
echo _('Select pollers to be attached to this new Remote Server');
echo _('Finalizing Setup');
echo _('Creating Export Task');
echo _('Generating Export Files');
echo _('The field is required');
echo _('Not a valid IP address');
echo _('Add server with wizard');
echo _('Select linked Remote Server');
echo _('as');
echo _('Server Configuration');
echo _('Attach poller to a master remote server');
echo _('Attach poller to additional remote servers');
echo _('Advanced: reverse Centreon Broker communication flow');
echo _('%s is not valid.');
echo _("You need to send '%s' in the request.");
echo _('Some database poller updates are not active; check your configuration');
echo _('Latency detected, check configuration for better optimization');
echo _('Do not check SSL certificate validation');
echo _('Do not use configured proxy to connect to this server');
